@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -686,7 +686,7 @@ def validate_docker_service_mysql_usage(filename, tpl):
         if not search(puppet_config, match_mysqlclient, no_op):
             print("ERROR: containerized service %s uses mysql but "
                   "puppet_config section does not include "
-                  "::tripleo::profile::base::database::mysql::client"
+                  "tripleo::profile::base::database::mysql::client"
                   % filename)
             return 1
 
@@ -1019,6 +1019,9 @@ def validate_service_hiera_interpol(f, tpl):
             if ('tripleo::profile::base::designate::rndc_allowed_addresses' in
                     path):
                 continue
+            # Omit Neutron ml2 overlay_ip_version
+            if 'neutron::plugins::ml2::overlay_ip_version' in path:
+                continue
 
             # Omit if not a part of {get_param: [ServiceNetMap ...
             if not enter_lists and path[-1] != 'get_param':
@@ -1026,6 +1029,10 @@ def validate_service_hiera_interpol(f, tpl):
             if enter_lists and path[-1] != 0 and path[-2] != 'get_param':
                 continue
 
+            # Omit if it is not a hiera config setting
+            if path[1] in ['kolla_config']:
+                continue
+
             path_str = ';'.join(str(x) for x in path)
             # NOTE(bogdando): Omit foo_network keys looking like a network
             # name. The only exception is allow anything under
